@@ -547,25 +547,24 @@
   if (quick) return(list(opt=opt,vcov=NA))
 
   if (is.null(myGrad) | !XconstrStdOpt ) {
-    if (!require("numDeriv")) {
-      opt$gradient <- naiveGrad(myObj, opt$estimate)
-    } else {
-      opt$gradient <- grad(myObj, opt$par, method=lava.options()$Dmethod)
-    }
+    ## if (!require("numDeriv")) {
+    ##   opt$gradient <- naiveGrad(myObj, opt$estimate)
+    ## } else {
+      opt$gradient <- numDeriv::grad(myObj, opt$par, method=lava.options()$Dmethod)
   } else {
-    opt$gradient <- myGrad(opt$estimate)
+      opt$gradient <- myGrad(opt$estimate)
   }
 
   if (!XconstrStdOpt) {
     myInformation <- function(theta) information(x,p=theta)
   } else {
   if (is.null(myInformation)) {
-    if (!require("numDeriv")) stop("I do not know how to calculate the asymptotic variance of this estimator.
-For numerical approximation please install the library 'numDeriv'.")
+##     if (!require("numDeriv")) stop("I do not know how to calculate the asymptotic variance of this estimator.
+## For numerical approximation please install the library 'numDeriv'.")
     if (!is.null(myGrad) & XconstrStdOpt)
-      myInformation <- function(theta) jacobian(myGrad, theta, method=lava.options()$Dmethod)
+      myInformation <- function(theta) numDeriv::jacobian(myGrad, theta, method=lava.options()$Dmethod)
     else {
-      myInformation <- function(theta) hessian(myObj, theta)
+      myInformation <- function(theta) numDeriv::hessian(myObj, theta)
     }
   }
 }
