@@ -18,7 +18,7 @@
 ##' @keywords survival models regression
 ##' @examples
 ##'
-##' m <- lvm()
+##' m <- lvm() 
 ##' distribution(m,~X2) <- binomial.lvm()
 ##' regression(m) <- T1~f(X1,-.5)+f(X2,0.3)
 ##' regression(m) <- T2~f(X2,0.6)
@@ -36,7 +36,7 @@
 ##' @param formula Formula (see details)
 ##' @param eventName Event names
 ##' @param \dots Additional arguments to lower levels functions
-eventTime <- function(object,formula,eventName,...){
+eventTime <- function(object,formula,eventName,...) {
   if (missing(formula)) return(object$attributes$eventHistory)
   ff <- as.character(formula)
   timeName <- all.vars(update.formula(formula,"~1"))
@@ -181,23 +181,108 @@ coxWeibull.lvm <- function(shape=1,scale,rate=1/scale) {
   return(f)
 }
 
+
+##' Add time-varying covariate effects to model
+##' 
+##' @title Time-dependent parameters
+##' @param object Model
+##' @param formula Formula with rhs specifying time-varying covariates
+##' @param rate Optional (log)-rate(ratio) parameters
+##' @param timecut Time intervals
+##' @param type Type of model (default piecewise constant intensity)
+##' @param ... Additional arguments to lower level functions
+##' @author Klaus K. Holst
 ##' @export
-coxExponential.lvm <- function(scale,rate,timecut=0){
+##' @examples
+##' 
+##' ## Piecewise constant hazard
+##' m <- lvm(y~1)
+##' m <- timedep(m,y~1,timecut=c(0,5),rate=c(0.5,0.3))
+##' 
+##' \dontrun{
+##' d <- sim(m,1e4); d$status <- TRUE
+##' dd <- mets::lifetable(Surv(y,status)~1,data=d,breaks=c(5));
+##' exp(coef(glm(events ~ offset(log(atrisk)) + -1 + interval, dd, family=poisson)))
+##' }
+##' 
+##' 
+##' ## Piecewise constant hazard and time-varying effect of z1
+##' m <- lvm(y~1)
+##' distribution(m,~z1) <- ones.lvm(0.5)
+##' R <- log(cbind(c(0.2,0.7,0.9),c(0.5,0.3,0.3)))
+##' m <- timedep(m,y~z1,timecut=c(0,3,5),rate=R)
+##' 
+##' \dontrun{
+##' d <- sim(m,1e4); d$status <- TRUE
+##' dd <- lifetable(Surv(y,status)~z1,data=d,breaks=c(3,5));
+##' exp(coef(glm(events ~ offset(log(atrisk)) + -1 + interval+z1:interval, dd, family=poisson)))
+##' }
+##' 
+##' 
+##' 
+##' ## Explicit simulation of time-varying effects
+##' m <- lvm(y~1)
+##' distribution(m,~z1) <- ones.lvm(0.5)
+##' distribution(m,~z2) <- binomial.lvm(p=0.5)
+##' #variance(m,~m1+m2) <- 0
+##' #regression(m,m1[m1:0] ~ z1) <- log(0.5)
+##' #regression(m,m2[m2:0] ~ z1) <- log(0.3)
+##' regression(m,m1 ~ z1,variance=0) <- log(0.5)
+##' regression(m,m2 ~ z1,variance=0) <- log(0.3)
+##' intercept(m,~m1+m2) <- c(-0.5,0)
+##' m <- timedep(m,y~m1+m2,timecut=c(0,5))
+##' 
+##' \dontrun{
+##' d <- sim(m,1e5); d$status <- TRUE
+##' dd <- lifetable(Surv(y,status)~z1,data=d,breaks=c(5))
+##' exp(coef(glm(events ~ offset(log(atrisk)) + -1 + interval + interval:z1, dd, family=poisson)))
+##' }
+timedep <- function(object,formula,rate,timecut,type="coxExponential.lvm",...) {
+    if (missing(timecut)) stop("'timecut' needed")
+    ##if (inherits(formula,"formula"))
+    ff <- getoutcome(formula)
+    simvars <- attributes(ff)$x
+    if (is.null(object$attributes$simvar)) {
+        object$attributes$simvar <- list(simvars)
+        names(object$attributes$simvar) <- ff
+    } else {
+        object$attributes$simvar[[ff]] <- simvars
+    }
+    if (missing(rate)) rate <- rep(1,length(timecut))
+    args <- list(timecut=timecut,rate=rate,...)
+    distribution(object,ff) <- do.call(type,args)
+    return(object)
+}
+
+
+##' @export
+coxExponential.lvm <- function(scale=1,rate,timecut){
     if (missing(rate)) rate=1/scale
     if (missing(scale)) scale=1/rate
-    if (length(rate)==1) {
+    if (missing(timecut)) {
         return(coxWeibull.lvm(shape=1,scale))
     }
-    if (length(rate)>length(timecut))
-        stop("Number of time-intervals (cuts) does not agree with number of rate parameters (beta0)")
+
+    if (NROW(rate)>length(timecut))
+        stop("Number of time-intervals (cuts) does not agree with number of rate parameters (beta0)")    
+    par <- paste(timecut,rate,sep=":")
+    if (is.matrix(rate)) par <- "..."
     timecut <- c(timecut,Inf)
     f <- function(n,mu,...) {
         Ai <- function() {
-            vals <- matrix(0,ncol=length(rate),nrow=n)
+            vals <- matrix(0,ncol=length(timecut)-1,nrow=n)
             ival <- numeric(n)
-            for (i in seq(length(rate))) {
+            if (is.matrix(rate)) {
+                mu <- cbind(mu[,1],cbind(1,as.matrix(mu[,-1]))%*%t(rate))
+                rate <- rep(1,length(timecut)-1)                
+            }   
+            for (i in seq(length(timecut)-1)) {
                 u <- -log(runif(n)) ##rexp(n,1)
-                vals[,i] <-  timecut[i] + u*exp(-mu)/(rate[i])
+                if (NCOL(mu)>1) {
+                    vals[,i] <-  timecut[i] + u*exp(-mu[,1]-mu[,i+1])/(rate[i])
+                } else {
+                    vals[,i] <-  timecut[i] + u*exp(-mu)/(rate[i])
+                }
                 idx <- which(vals[,i]<=timecut[i+1] & ival==0)
                 ival[idx] <- vals[idx,i]
             }
@@ -205,26 +290,38 @@ coxExponential.lvm <- function(scale,rate,timecut=0){
         }
         Ai()
     }
+    attributes(f)$family <- list(family="CoxExponential",par=par)
     return(f)
 }
 
 ##' @export
-aalenExponential.lvm <- function(scale,rate,timecut=0){
+aalenExponential.lvm <- function(scale=1,rate,timecut=0){
     if (missing(rate)) rate=1/scale
     if (missing(scale)) scale=1/rate
-    if (length(rate)==1) {
+    if (missing(timecut)==1) {
         return(coxWeibull.lvm(shape=1,scale))
     }
+    
     if (length(rate)>length(timecut))
         stop("Number of time-intervals (cuts) does not agree with number of rate parameters (beta0)")
+    par <- paste(timecut,rate,sep=":")
+    if (is.matrix(rate)) par <- "..."
     timecut <- c(timecut,Inf)
     f <- function(n,mu,...) {
         Ai <- function() {
-            vals <- matrix(0,ncol=length(rate),nrow=n)
+            vals <- matrix(0,ncol=length(timecut)-1,nrow=n)
             ival <- numeric(n)
-            for (i in seq(length(rate))) {
+            if (is.matrix(rate)) {
+                mu <- cbind(mu[,1],cbind(1,as.matrix(mu[,-1]))%*%t(rate))
+                rate <- rep(1,length(timecut)-1)                
+            }
+            for (i in seq(length(timecut)-1)) {
                 u <- -log(runif(n)) ##rexp(n,1)
-                vals[,i] <-  timecut[i] + u/(rate[i]+mu)
+                if (NCOL(mu)>1) {
+                    vals[,i] <-  timecut[i] + u/(rate[i]+mu[,1]+mu[,i+1])
+                } else {
+                    vals[,i] <-  timecut[i] + u/(rate[i]+mu)
+                }
                 idx <- which(vals[,i]<=timecut[i+1] & ival==0)
                 ival[idx] <- vals[idx,i]
             }
@@ -232,6 +329,7 @@ aalenExponential.lvm <- function(scale,rate,timecut=0){
         }
         Ai()
     }
+    attributes(f)$family <- list(family="aalenExponential",par=par)
     return(f)
 }
 
