@@ -258,8 +258,8 @@ function(x, sparse=FALSE,standard=TRUE,zeroones=FALSE,deriv=FALSE,mean=TRUE) { #
   if (zeroones) {
     if (sparse) {
       if (!require("Matrix")) stop("package Matrix not available")
-      Ik <- Matrix:::Diagonal(length(obs))
-      Im <- Matrix:::Diagonal(ncol(A))
+      Ik <- Matrix::Diagonal(length(obs))
+      Im <- Matrix::Diagonal(ncol(A))
       Kkk <- NULL
       J <- as(J, "sparseMatrix")
       Jy <- as(Jy, "sparseMatrix")
